@@ -31,12 +31,16 @@ class CRUD(APIRouter):
             # except RuntimeError:
             #     loop = asyncio.new_event_loop()
             #     asyncio.set_event_loop(loop)
-            loop = asyncio.new_event_loop()
-            asyncio.set_event_loop(loop)
-            loop.run_until_complete(asyncio.gather(database()))
-            #loop.run_until_complete(database())
-            loop.stop()
-            loop.close()
+            # loop = asyncio.new_event_loop()
+            # asyncio.set_event_loop(loop)
+            # #loop.run_until_complete(asyncio.gather(database()))
+            # loop.run_until_complete(database())
+            # loop.stop()
+            # loop.close()
+            async def run():
+                await asyncio.gather(database())
+
+            asyncio.run(run())
         else:
             database()
 
